@@ -10,6 +10,7 @@ import (
 	"log"
 	"os"
 	"os/exec"
+	"regexp"
 	"runtime"
 	"strconv"
 	"strings"
@@ -169,8 +170,12 @@ func purgeDir(dir string, callingFunction string) {
 	}
 }
 
-func executeCommand(command string, timeout int, allowFail bool) ExecResult {
-	Debugf("Executing " + command)
+func executeCommand(command string, commandDir string, timeout int, allowFail bool) ExecResult {
+	if len(commandDir) > 0 {
+		Debugf("Executing " + command + " in cwd " + commandDir)
+	} else {
+		Debugf("Executing " + command)
+	}
 	parts := strings.SplitN(command, " ", 2)
 	cmd := parts[0]
 	cmdArgs := []string{}
@@ -184,7 +189,11 @@ func executeCommand(command string, timeout int, allowFail bool) ExecResult {
 	}
 
 	before := time.Now()
-	out, err := exec.Command(cmd, cmdArgs...).CombinedOutput()
+	execCommand := exec.Command(cmd, cmdArgs...)
+	if len(commandDir) > 0 {
+		execCommand.Dir = commandDir
+	}
+	out, err := execCommand.CombinedOutput()
 	duration := time.Since(before).Seconds()
 	er := ExecResult{0, string(out)}
 	if msg, ok := err.(*exec.ExitError); ok { // there is error code
@@ -232,7 +241,7 @@ func checkForAndExecutePostrunCommand() {
 		postrunCommandString = strings.Replace(postrunCommandString, "$modifiedenvs", needSyncEnvText, -1)
 		postrunCommandString = strings.Replace(postrunCommandString, "$branchparam", branchParam, -1)
 
-		er := executeCommand(postrunCommandString, config.Timeout, false)
+		er := executeCommand(postrunCommandString, "", config.Timeout, false)
 		Debugf("postrun command '" + postrunCommandString + "' terminated with exit code " + strconv.Itoa(er.returnCode))
 	}
 }
@@ -323,3 +332,11 @@ func readDeployResultFile(file string) DeployResult {
 	return dr
 
 }
+
+func stripComponent(component string, env string) string {
+	if regexp.MustCompile(`^/.*/$`).MatchString(component) {
+		return regexp.MustCompile(component[1:len(component)-1]).ReplaceAllString(env, "")
+	} else {
+		return strings.TrimPrefix(env, component)
+	}
+}
