@@ -60,12 +60,12 @@ func resolvePuppetEnvironment(tags bool, outputNameTag string) {
 			if success := doMirrorOrUpdate(controlRepoGit, workDir, 0); success {
 
 				// get all branches
-				er := executeCommand("git --git-dir "+workDir+" branch", config.Timeout, false)
+				er := executeCommand("git --git-dir "+workDir+" branch", "", config.Timeout, false)
 				outputBranches := er.output
 				outputTags := ""
 
 				if tags {
-					er := executeCommand("git --git-dir "+workDir+" tag", config.Timeout, false)
+					er := executeCommand("git --git-dir "+workDir+" tag", "", config.Timeout, false)
 					outputTags = er.output
 				}
 
@@ -125,7 +125,17 @@ func resolvePuppetEnvironment(tags bool, outputNameTag string) {
 							renamedBranch := branch
 							if (len(outputNameTag) > 0) && (len(branchParam) > 0) {
 								renamedBranch = outputNameTag
-								Debugf("Renaming branch " + branch + " to " + renamedBranch)
+								Debugf("Renaming branch " + branch + " to " + renamedBranch + " from  source " + source + " " + sa.Remote)
+							}
+
+							// https://github.com/puppetlabs/r10k/blob/main/doc/dynamic-environments/configuration.mkd#strip_component
+							if len(sa.StripComponent) != 0 {
+								stripRenamedBranch := stripComponent(sa.StripComponent, renamedBranch)
+								if stripRenamedBranch != renamedBranch {
+									// only print this if the branch was definately renamed, because of the strip component
+									Debugf("Renaming branch " + renamedBranch + " to " + stripRenamedBranch + ", because of strip_component in source " + source + " " + sa.Remote)
+									renamedBranch = stripRenamedBranch
+								}
 							}
 
 							if sa.AutoCorrectEnvironmentNames == "correct" || sa.AutoCorrectEnvironmentNames == "correct_and_warn" {
@@ -133,15 +143,19 @@ func resolvePuppetEnvironment(tags bool, outputNameTag string) {
 								renamedBranch = reInvalidCharacters.ReplaceAllString(renamedBranch, "_")
 								if oldBranch != renamedBranch {
 									if sa.AutoCorrectEnvironmentNames == "correct_and_warn" {
-										Warnf("Renaming branch " + oldBranch + " to " + renamedBranch)
+										Warnf("Renaming branch " + oldBranch + " to " + renamedBranch + " from  source " + source + " " + sa.Remote)
 									} else {
-										Debugf("Renaming branch " + oldBranch + " to " + renamedBranch)
+										Debugf("Renaming branch " + oldBranch + " to " + renamedBranch + " from  source " + source + " " + sa.Remote)
 									}
 								}
 							}
 
 							mutex.Lock()
-							allEnvironments[prefix+renamedBranch] = true
+							if _, ok := allEnvironments[prefix+renamedBranch]; !ok {
+								allEnvironments[prefix+renamedBranch] = true
+							} else {
+								Fatalf("Renamed environment naming conflict detected with renamed environment " + prefix + renamedBranch)
+							}
 							mutex.Unlock()
 							targetDir := filepath.Join(sa.Basedir, prefix+strings.Replace(renamedBranch, "/", "_", -1))
 							targetDir = normalizeDir(targetDir)
@@ -475,8 +489,10 @@ func skipBasedOnFilterCommand(branch string, sourceName string, sa Source, workD
 	branchFilterCommand = strings.ReplaceAll(branchFilterCommand, "$G10K_NAME", sourceName)
 	branchFilterCommand = strings.ReplaceAll(branchFilterCommand, "$GIT_DIR", workDir)
 	Debugf("executing filter_command: " + branchFilterCommand)
-	er := executeCommand(branchFilterCommand, 30, true)
-	fmt.Printf("%+v", er)
+	er := executeCommand(branchFilterCommand, "", 30, true)
+	if debug {
+		fmt.Printf("filter_command %s result: %+v", branchFilterCommand, er)
+	}
 	return er.returnCode != 0
 }
 
